@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2016
+# Copyright (C) 2015-2017
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -48,7 +48,7 @@ class Game(TelegramObject):
                  title,
                  description,
                  photo,
-                 text='',
+                 text=None,
                  text_entities=None,
                  animation=None,
                  **kwargs):
@@ -73,6 +73,8 @@ class Game(TelegramObject):
         if not data:
             return None
 
+        data = super(Game, Game).de_json(data, bot)
+
         data['photo'] = PhotoSize.de_list(data.get('photo'), bot)
         data['text_entities'] = MessageEntity.de_list(data.get('text_entities'), bot)
         data['animation'] = Animation.de_json(data.get('animation'), bot)
