@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2016
+# Copyright (C) 2015-2017
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -16,13 +16,31 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-"""This module contains the classes that represent Telegram
-InlineQueryResultPhoto"""
+"""This module contains the classes that represent Telegram InlineQueryResultPhoto"""
 
 from telegram import InlineQueryResult, InlineKeyboardMarkup, InputMessageContent
 
 
 class InlineQueryResultPhoto(InlineQueryResult):
+    """Represents a link to a photo. By default, this photo will be sent by the user with optional
+    caption. Alternatively, you can use input_message_content to send a message with the specified
+    content instead of the photo.
+
+    Attributes:
+        photo_url (str): A valid URL of the photo. Photo must be in jpeg format. Photo size must
+            not exceed 5MB.
+        thumb_url (str): URL of the thumbnail for the photo.
+        photo_width (Optional[int]): Width of the photo.
+        photo_height (Optional[int]): Height of the photo.
+        title (Optional[str]): Title for the result.
+        description	(Optional[str]): Short description of the result.
+        caption (Optional[str]): Caption of the photo to be sent, 0-200 characters.
+        reply_markup (Optional[:class:`telegram.InlineKeyboardMarkup`]): Inline keyboard attached
+            to the message.
+        input_message_content (Optional[:class:`telegram.InputMessageContent`]): Content of the
+            message to be sent instead of the photo.
+
+    """
 
     def __init__(self,
                  id,
