@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2016
+# Copyright (C) 2015-2017
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -25,7 +25,7 @@ from telegram import InputMessageContent
 class InputContactMessageContent(InputMessageContent):
     """Base class for Telegram InputContactMessageContent Objects"""
 
-    def __init__(self, phone_number, first_name, last_name=None):
+    def __init__(self, phone_number, first_name, last_name=None, **kwargs):
         # Required
         self.phone_number = phone_number
         self.first_name = first_name
@@ -33,5 +33,5 @@ class InputContactMessageContent(InputMessageContent):
         self.last_name = last_name
 
     @staticmethod
-    def de_json(data):
+    def de_json(data, bot):
         return InputContactMessageContent(**data)
