@@ -2,7 +2,7 @@
 # pylint: disable=C0103,W0622
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2016
+# Copyright (C) 2015-2017
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -44,7 +44,14 @@ class User(TelegramObject):
         bot (Optional[Bot]): The Bot to use for instance methods
     """
 
-    def __init__(self, id, first_name, type='', last_name='', username='', bot=None, **kwargs):
+    def __init__(self,
+                 id,
+                 first_name,
+                 type=None,
+                 last_name=None,
+                 username=None,
+                 bot=None,
+                 **kwargs):
         # Required
         self.id = int(id)
         self.first_name = first_name
@@ -55,6 +62,8 @@ class User(TelegramObject):
 
         self.bot = bot
 
+        self._id_attrs = (self.id,)
+
     @property
     def name(self):
         """str: """
@@ -77,6 +86,8 @@ class User(TelegramObject):
         if not data:
             return None
 
+        data = super(User, User).de_json(data, bot)
+
         return User(bot=bot, **data)
 
     def get_profile_photos(self, *args, **kwargs):
