@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015 Leandro Toledo de Souza <leandrotoeldodesouza@gmail.com>
+# Copyright (C) 2015-2017
+# Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser Public License as published by
@@ -15,8 +16,7 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-
-"""This module contains a object that represents a Telegram Voice"""
+"""This module contains an object that represents a Telegram Voice."""
 
 from telegram import TelegramObject
 
@@ -32,29 +32,30 @@ class Voice(TelegramObject):
 
     Args:
         file_id (str):
+        duration (Optional[int]):
         **kwargs: Arbitrary keyword arguments.
 
     Keyword Args:
-        duration (Optional[int]):
         mime_type (Optional[str]):
         file_size (Optional[int]):
     """
 
-    def __init__(self,
-                 file_id,
-                 **kwargs):
+    def __init__(self, file_id, duration, mime_type=None, file_size=None, **kwargs):
         # Required
         self.file_id = str(file_id)
+        self.duration = int(duration)
         # Optionals
-        self.duration = int(kwargs.get('duration', 0))
-        self.mime_type = str(kwargs.get('mime_type', ''))
-        self.file_size = int(kwargs.get('file_size', 0))
+        self.mime_type = mime_type
+        self.file_size = file_size
+
+        self._id_attrs = (self.file_id,)
 
     @staticmethod
-    def de_json(data):
+    def de_json(data, bot):
         """
         Args:
-            data (str):
+            data (dict):
+            bot (telegram.Bot)
 
         Returns:
             telegram.Voice:
@@ -62,4 +63,6 @@ class Voice(TelegramObject):
         if not data:
             return None
 
+        data = super(Voice, Voice).de_json(data, bot)
+
         return Voice(**data)
